summaryrefslogtreecommitdiffstats
path: root/tools/slang-test/slangc-tool.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tools/slang-test/slangc-tool.cpp')
-rw-r--r--tools/slang-test/slangc-tool.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/tools/slang-test/slangc-tool.cpp b/tools/slang-test/slangc-tool.cpp
index 159e6faf2..ff44c0db6 100644
--- a/tools/slang-test/slangc-tool.cpp
+++ b/tools/slang-test/slangc-tool.cpp
@@ -14,12 +14,12 @@ SlangResult SlangCTool::innerMain(StdWriters* stdWriters, slang::IGlobalSession*
// Assume we will used the shared session
ComPtr<slang::IGlobalSession> session(sharedSession);
- // The sharedSession always has a pre-loaded stdlib.
- // This differed test checks if the command line has an option to setup the stdlib.
- // If so we *don't* use the sharedSession, and create a new stdlib-less session just for this compilation.
- if (TestToolUtil::hasDeferredStdLib(Index(argc - 1), argv + 1))
+ // The sharedSession always has a pre-loaded core module.
+ // This differed test checks if the command line has an option to setup the core module.
+ // If so we *don't* use the sharedSession, and create a new session without the core module just for this compilation.
+ if (TestToolUtil::hasDeferredCoreModule(Index(argc - 1), argv + 1))
{
- SLANG_RETURN_ON_FAIL(slang_createGlobalSessionWithoutStdLib(SLANG_API_VERSION, session.writeRef()));
+ SLANG_RETURN_ON_FAIL(slang_createGlobalSessionWithoutCoreModule(SLANG_API_VERSION, session.writeRef()));
}
ComPtr<slang::ICompileRequest> compileRequest;